@@ -1,7 +1,7 @@
 package Perinci::Tx::Manager;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $DATE = '2015-08-19'; # DATE
+our $VERSION = '0.52'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,7 +21,8 @@ use UUID::Random;
 
 # patch, add special action to just retrieve code and meta
 require Perinci::Access::Schemeless;
-package Perinci::Access::Schemeless;
+package
+    Perinci::Access::Schemeless;
 
 sub actionmeta_get_code_and_meta { +{
     applies_to => ['function'],
@@ -1394,7 +1395,7 @@ Perinci::Tx::Manager - A Rinci transaction manager
 
 =head1 VERSION
 
-This document describes version 0.51 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2015-08-18.
+This document describes version 0.52 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2015-08-19.
 
 =head1 SYNOPSIS
 
